==> jc-1.4.0.tar.gz: java/awt/Insets.h <==
// public class java.awt.Insets

// class file dependencies
// @dep_class ec052a1e3584fd11 java_awt_Insets
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_Insets_H_
#define _JC_java_awt_Insets_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_Insets$sub_refs	_jc_java_awt_Insets$sub_refs;
typedef struct _jc_java_awt_Insets$sub_nonrefs	_jc_java_awt_Insets$sub_nonrefs;
typedef struct _jc_java_awt_Insets$refs	_jc_java_awt_Insets$refs;
typedef struct _jc_java_awt_Insets$nonrefs	_jc_java_awt_Insets$nonrefs;
typedef struct _jc_java_awt_Insets$object	_jc_java_awt_Insets$object;

typedef struct _jc_java_awt_Insets$fields_struct	_jc_java_awt_Insets$fields_struct;
typedef const struct _jc_java_awt_Insets$vmethods	_jc_java_awt_Insets$vmethods;
typedef const struct _jc_java_awt_Insets$vtable	_jc_java_awt_Insets$vtable;
typedef const struct _jc_java_awt_Insets$vtype	_jc_java_awt_Insets$vtype;

// Class fields structure
struct _jc_java_awt_Insets$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_Insets$fields_struct _jc_java_awt_Insets$class_fields;

// Constructors
extern void _jc_java_awt_Insets$method$_init$b5870f7bfece007a(_jc_env *, struct _jc_java_awt_Insets$object *, jint, jint, jint, jint);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_awt_Insets$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_awt_Insets$object *);
extern jboolean _jc_java_awt_Insets$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_awt_Insets$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java_awt_Insets$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_awt_Insets$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_Insets$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_awt_Insets$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_Insets$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_awt_Insets$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_awt_Insets$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_awt_Insets$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_awt_Insets$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_awt_Insets$object *);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_awt_Insets$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_awt_Insets$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_awt_Insets$object *);
};

// Vtable
struct _jc_java_awt_Insets$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Insets$vmethods	java_awt_Insets;
};

// Vtype
struct _jc_java_awt_Insets$vtype {
	_jc_type			type;
	_jc_java_awt_Insets$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Insets$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_Insets$refs {
    _jc_java_awt_Insets$sub_refs	java_awt_Insets;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Insets$sub_nonrefs {
	jint	top;
	jint	left;
	jint	bottom;
	jint	right;
};

// Non-reference instance fields (object)
struct _jc_java_awt_Insets$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Insets$sub_nonrefs	java_awt_Insets;
};

// Object instance structure
struct _jc_java_awt_Insets$object {
	_jc_java_awt_Insets$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Insets$vtype	*vtype;
	_jc_java_awt_Insets$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Insets$vtype _jc_java_awt_Insets$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Insets, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Insets$class_object;

#endif	/* _JC_java_awt_Insets_H_ */

==> jc-1.4.6.tar.gz: java/awt/Insets.h <==
// public class java.awt.Insets

// class file dependencies
// @dep_class ec052a1e3584fd11 java_awt_Insets
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_Insets_H_
#define _JC_java_awt_Insets_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_Insets$sub_refs	_jc_java_awt_Insets$sub_refs;
typedef struct _jc_java_awt_Insets$sub_nonrefs	_jc_java_awt_Insets$sub_nonrefs;
typedef struct _jc_java_awt_Insets$refs	_jc_java_awt_Insets$refs;
typedef struct _jc_java_awt_Insets$nonrefs	_jc_java_awt_Insets$nonrefs;
typedef struct _jc_java_awt_Insets$object	_jc_java_awt_Insets$object;

typedef struct _jc_java_awt_Insets$fields_struct	_jc_java_awt_Insets$fields_struct;
typedef const struct _jc_java_awt_Insets$vmethods	_jc_java_awt_Insets$vmethods;
typedef const struct _jc_java_awt_Insets$vtable	_jc_java_awt_Insets$vtable;
typedef const struct _jc_java_awt_Insets$vtype	_jc_java_awt_Insets$vtype;

// Class fields structure
struct _jc_java_awt_Insets$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_Insets$fields_struct _jc_java_awt_Insets$class_fields;

// Constructors
extern void _jc_java_awt_Insets$method$_init$b5870f7bfece007a(_jc_env *, struct _jc_java_awt_Insets$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_awt_Insets$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_awt_Insets$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_Insets$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_awt_Insets$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_Insets$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_awt_Insets$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_Insets$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_awt_Insets$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_Insets$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_awt_Insets$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_awt_Insets$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_awt_Insets$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_awt_Insets$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_awt_Insets$object *) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_awt_Insets$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_awt_Insets$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_awt_Insets$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_Insets$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Insets$vmethods	java_awt_Insets;
};

// Vtype
struct _jc_java_awt_Insets$vtype {
	_jc_type			type;
	_jc_java_awt_Insets$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Insets$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_Insets$refs {
    _jc_java_awt_Insets$sub_refs	java_awt_Insets;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Insets$sub_nonrefs {
	jint	top;
	jint	left;
	jint	bottom;
	jint	right;
};

// Non-reference instance fields (object)
struct _jc_java_awt_Insets$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Insets$sub_nonrefs	java_awt_Insets;
};

// Object instance structure
struct _jc_java_awt_Insets$object {
	_jc_java_awt_Insets$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Insets$vtype	*vtype;
	_jc_java_awt_Insets$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Insets$vtype _jc_java_awt_Insets$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Insets, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Insets$class_object;

#endif	/* _JC_java_awt_Insets_H_ */
